/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Security Delegation Clients - Main function for the tools
 *
 *  Authors: Zoltan Farkas <Zoltan.Farkas@cern.ch>
 *
 */

#ifndef TOOL_MAIN_H
#define TOOL_MAIN_H

#include <glib.h>

/**********************************************************************
 * Constants
 */


/**********************************************************************
 * Data type definitions
 */


/**********************************************************************
 * Prototypes
 */

/* Parse tool-specific command line option */
int tool_parse_cmdline(int option, char *opt_arg);

/* Perform tool operation */
int tool_doit(glite_delegation_ctx *ctx, int argc, char *argv[]);

/**********************************************************************
 * Utility functions
 */

/* Print an informational message */
void info(const char *fmt, ...);

/* Print an error message */
void error(const char *fmt, ...);

/**********************************************************************
 * Global variables exported by the tool
 */

/* Tool-specific command line options */
extern const char *tool_options;

/* Tool-specific help message */
extern const char *tool_help;

/* Tool-specific usage instructions */
extern const char *tool_usage;

/* If the tool should keep silence */
extern int quiet_flag;

/* If the tool should print many messages */
extern int verbose_flag;

#endif /* TOOL_MAIN_H */
