/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  gLite Security Delegation Clients - Get Proxy
 *
 *  Authors: Zoltan Farkas <Zoltan.Farkas@cern.ch>
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glite/data/delegation/c/delegation-simple.h>

#include "delegation-main.h"

#include <stdlib.h>
#include <stdio.h>
#include <time.h>

/**********************************************************************
 * Global variables
 */

/* Usage message */
const char *tool_usage = "[DELEGATION_ID]";

/* Help message */
const char *tool_help = "";

/* getguid-specific command line options */
const char *tool_options = "";

const char *default_datetime_format = "%F %T %Z";
const int default_datetime_length = 100;

/**********************************************************************
 * Tool implementation
 */

int tool_doit(glite_delegation_ctx *ctx, int argc, char *argv[])
{
	int ret;
	char *delegation_id;
    time_t exp_time, current_time;
    struct tm *exp_tm;
    char datetime[default_datetime_length];
	
	delegation_id = (argc ? argv[0] : "");

	ret = glite_delegation_info(ctx, delegation_id, &exp_time);
	if (-1 == ret)
	{
		error("Error: %s", glite_delegation_get_error(ctx));
		return -1;
	}

    info(" Expiration time of the delegated [%s] credential is:", delegation_id);
    exp_tm = localtime(&exp_time);
    if(exp_tm == NULL || 
       strftime(datetime, default_datetime_length, default_datetime_format, exp_tm) == 0) 
    {
        error("Could not format the expiration time");
        return -1;
    }
    printf("%s\n", datetime);

    current_time = time(NULL);
    info("Remaining time is %ld hours and %ld minutes.", 
        (long int)((exp_time - current_time) / 3600),
        (long int)((exp_time - current_time) % 60));

	return 0;
}

/**********************************************************************
 * Command line parsing
 */

int tool_parse_cmdline(int c G_GNUC_UNUSED, char *opt_arg G_GNUC_UNUSED)
{
	return -1;
}

